==> haskell-text-latin1-0.3.1-274-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-KWGocP9nJnjG3cUSu8DOh1
key:                  text-latin1-0.3.1-KWGocP9nJnjG3cUSu8DOh1
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  a9c48ec20523edfffba349f03c07ed82
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-KWGocP9nJnjG3cUSu8DOh1
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-5qBt9JHinkAC9eq4HZukmL
    data-checked-0.3-2xOO5aVFI22KJDTvb8lvZD
    hashable-1.4.4.0-DGEtQXeqhKmCCbhJMtBsUM text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3.1-275-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-EgIxd9OAqGm3wO9sKVcGDZ
key:                  text-latin1-0.3.1-EgIxd9OAqGm3wO9sKVcGDZ
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  1c5673ccc6efffcb258484a6b19e139f
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-EgIxd9OAqGm3wO9sKVcGDZ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-6fVgEt7vrFc1sDHTeWeWXd
    data-checked-0.3-2xOO5aVFI22KJDTvb8lvZD
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
